@@ -211,7 +211,8 @@ toc_pager_init (YelpTocPager *pager)
     priv->parser = xmlNewParserCtxt ();
 
     priv->unique_hash   = g_hash_table_new (g_str_hash, g_str_equal);
-    priv->category_hash = g_hash_table_new (g_str_hash, g_str_equal);
+    priv->category_hash = g_hash_table_new_full (g_str_hash, g_str_equal,
+						 g_free,     NULL);
 
     priv->cancel       = 0;
     priv->pause_count  = 0;
@@ -301,7 +302,7 @@ toc_pager_process (YelpPager *pager)
 	    priv->man_dir_pending = g_slist_prepend (priv->man_dir_pending,
 						     g_strdup (paths[i]));
 
-	g_free (paths);
+	g_strfreev (paths);
 	g_free (manpath);
     }
 
@@ -484,15 +485,6 @@ process_omf_pending (YelpTocPager *pager)
 			       XML_PARSE_NONET    );
     if (!omf_doc) {
 	g_warning (_("Could not load the OMF file '%s'."), file);
-	/* FIXME:
-	 * There is a bug in libxml2 (#131745) that prevents files from being
-	 * parsed with a parser context after that context has failed on any
-	 * single file.  To work around this, we'll free the parser and make
-	 * a new one.  Remove the next two lines once configure.in requires
-	 * a version of libxml2 that has the bug fixed.
-	 */
-	xmlFreeParserCtxt (priv->parser);
-	priv->parser = xmlNewParserCtxt ();
 	goto done;
     }
 
@@ -969,7 +961,7 @@ toc_hash_metafile (YelpTocPager *pager, YelpMetafile *meta)
 	    (GSList *) g_hash_table_lookup (priv->category_hash, catstr);
 	metas = g_slist_prepend (metas, meta);
 
-	g_hash_table_insert (priv->category_hash, catstr, metas);
+	g_hash_table_insert (priv->category_hash, g_strdup (catstr), metas);
     }
 
     priv->idx_pending = g_slist_prepend (priv->idx_pending, meta);
@@ -988,11 +980,12 @@ toc_unhash_metafile (YelpTocPager *pager, YelpMetafile *meta)
 	GSList *metas =
 	    (GSList *) g_hash_table_lookup (pager->priv->category_hash, catstr);
 
-	if (metas) {
-	    metas = g_slist_remove (metas, meta);
+	metas = g_slist_remove (metas, meta);
+	if (metas)
 	    g_hash_table_insert (pager->priv->category_hash,
-				 catstr, metas);
-	}
+				 g_strdup (catstr), metas);
+	else
+	    g_hash_table_remove (pager->priv->category_hash, catstr);
     }
 
     priv->idx_pending = g_slist_remove (priv->idx_pending, meta);
